import { CodeAnalyzer } from '@salesforce/code-analyzer-core';
import { Display } from '../Display';
export interface ProgressEventListener {
    listen(...codeAnalyzers: CodeAnalyzer[]): void;
    stopListening(): void;
}
declare abstract class ProgressSpinner {
    private readonly display;
    private readonly tickTime;
    private tickIntervalId;
    private _isSpinning;
    private startTime;
    protected constructor(display: Display, tickTime?: number);
    protected startSpinning(action: string): void;
    protected updateSpinner(): void;
    protected stopSpinning(): void;
    protected isSpinning(): boolean;
    /**
     * Return the number of seconds (rounded down) that the spinner has been spinning.
     * @protected
     */
    protected getSecondsSpentSpinning(): number;
    protected abstract createInProgressSpinnerStatus(): string;
    protected abstract createFinishedSpinnerStatus(): string;
}
export declare class RuleSelectionProgressSpinner extends ProgressSpinner implements ProgressEventListener {
    private isListening;
    private engineNames;
    private readonly completionPercentages;
    /**
     * @param display The display with which to show output to the user
     * @param tickTime A number of milliseconds to wait between automatic ticks. Defaults to 1000. Negative values disable ticking.
     */
    constructor(display: Display, tickTime?: number);
    listen(...codeAnalyzers: CodeAnalyzer[]): void;
    stopListening(): void;
    private handleEvent;
    protected createInProgressSpinnerStatus(): string;
    protected createFinishedSpinnerStatus(): string;
}
export declare class EngineRunProgressSpinner extends ProgressSpinner implements ProgressEventListener {
    private isListening;
    /**
     * Mapping from each engine's name to a number indicating its completion percentage.
     * @private
     */
    private progressMap;
    /**
     * @param display The display with which to show output to the user
     * @param tickTime A number of milliseconds to wait between automatic ticks. Defaults to 1000. Negative values disable ticking.
     */
    constructor(display: Display, tickTime?: number);
    listen(...codeAnalyzers: CodeAnalyzer[]): void;
    stopListening(): void;
    private handleEvent;
    protected createInProgressSpinnerStatus(): string;
    protected createFinishedSpinnerStatus(): string;
}
export {};
