"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.ConfigFileWriter = void 0;
const node_path_1 = __importDefault(require("node:path"));
const node_fs_1 = __importDefault(require("node:fs"));
const ConfigModel_1 = require("../models/ConfigModel");
const messages_1 = require("../messages");
const FileUtil_1 = require("../utils/FileUtil");
class ConfigFileWriter {
    file;
    format;
    display;
    constructor(file, format, display) {
        this.file = file;
        this.format = format;
        this.display = display;
    }
    async write(model) {
        // Only write to the file if it doesn't already exist, or if the user confirms that they want to overwrite it.
        if (!(await (0, FileUtil_1.exists)(this.file)) || await this.display.confirm((0, messages_1.getMessage)(messages_1.BundleName.ConfigWriter, 'prompt.overwrite-existing-file', [this.file]))) {
            node_fs_1.default.writeFileSync(this.file, model.toFormattedOutput(this.format));
            return true;
        }
        else {
            return false;
        }
    }
    static fromFile(file, display) {
        const ext = node_path_1.default.extname(file).toLowerCase();
        if (ext === '.yaml' || ext === '.yml') {
            return new ConfigFileWriter(file, ConfigModel_1.OutputFormat.RAW_YAML, display);
        }
        else {
            throw new Error((0, messages_1.getMessage)(messages_1.BundleName.ConfigWriter, 'error.unrecognized-file-format', [file]));
        }
    }
}
exports.ConfigFileWriter = ConfigFileWriter;
//# sourceMappingURL=ConfigWriter.js.map